@@ -7,6 +7,7 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/require"
+
 	"gitlab.com/gitlab-org/cli/internal/git"
 	"gitlab.com/gitlab-org/cli/internal/run"
 	"gitlab.com/gitlab-org/cli/internal/testing/cmdtest"
@@ -88,7 +89,7 @@ func Test_stackAmendCmd(t *testing.T) {
 				require.Nil(t, err)
 			}
 
-			output, err := amendFunc(f, tc.args, getText, tc.description)
+			output, err := amendFunc(t.Context(), f, tc.args, getText, tc.description)
 
 			if tc.wantErr {
 				require.ErrorContains(t, err, tc.expected)
