@@ -3,7 +3,7 @@ package glrepo
 import (
 	"fmt"
 
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 )
 
 func TestProject(owner, repo string) Interface {
